@@ -20,7 +20,9 @@ from .const import (
     COLOR_MODE_RGBWW,
     EFFECT_MUSIC,
     EFFECT_RANDOM,
+    NEVER_TIME,
     PRESET_MUSIC_MODE,
+    PUSH_UPDATE_INTERVAL,
     STATE_BLUE,
     STATE_COOL_WHITE,
     STATE_GREEN,
@@ -44,7 +46,6 @@ from .protocol import (
 from .scanner import FluxLEDDiscovery
 from .timer import LedTimer
 from .utils import color_temp_to_white_levels, rgbw_brightness, rgbww_brightness
-from .const import PUSH_UPDATE_INTERVAL, NEVER_TIME
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -54,8 +55,8 @@ MAX_UPDATES_WITHOUT_RESPONSE = 4
 DEVICE_CONFIG_WAIT_SECONDS = (
     3.5  # time it takes for the device to respond after a config change
 )
-POWER_STATE_TIMEOUT = 0.6
-POWER_CHANGE_ATTEMPTS = 3
+POWER_STATE_TIMEOUT = 1.2
+POWER_CHANGE_ATTEMPTS = 6
 
 
 class AIOWifiLedBulb(LEDENETDevice):
@@ -64,7 +65,7 @@ class AIOWifiLedBulb(LEDENETDevice):
     def __init__(
         self,
         ipaddr: str,
-        port: int = 5577,
+        port: int = 0,
         timeout: float = 5,
         discovery: Optional[FluxLEDDiscovery] = None,
     ) -> None:
@@ -183,9 +184,9 @@ class AIOWifiLedBulb(LEDENETDevice):
         await self._async_send_msg(self._protocol.construct_state_query())
 
     async def _async_wait_state_change(
-        self, futures: List["asyncio.Future[Any]"], state: bool
+        self, futures: List["asyncio.Future[Any]"], state: bool, timeout: float
     ) -> bool:
-        done, _ = await asyncio.wait(futures, timeout=POWER_STATE_TIMEOUT)
+        done, _ = await asyncio.wait(futures, timeout=timeout)
         if done and self.is_on == state:
             return True
         return False
@@ -203,7 +204,7 @@ class AIOWifiLedBulb(LEDENETDevice):
         await self._async_send_msg(self._protocol.construct_state_change(state))
         _LOGGER.debug("%s: Waiting for power state response", self.ipaddr)
         if await self._async_wait_state_change(
-            [state_future, power_state_future], state
+            [state_future, power_state_future], state, POWER_STATE_TIMEOUT * (3 / 8)
         ):
             return True
         if power_state_future.done() and accept_any_power_state_response:
@@ -223,8 +224,15 @@ class AIOWifiLedBulb(LEDENETDevice):
         if state_future.done():
             state_future = asyncio.Future()
             self._state_futures.append(state_future)
+        pending: "List[asyncio.Future[Any]]" = [state_future]
+        if not power_state_future.done():
+            # If the power state still hasn't responded
+            # we want to stop waiting as soon as it does
+            pending.append(power_state_future)
         await self._async_send_state_query()
-        if await self._async_wait_state_change([state_future], state):
+        if await self._async_wait_state_change(
+            pending, state, POWER_STATE_TIMEOUT * (5 / 8)
+        ):
             return True
         _LOGGER.debug(
             "%s: State query did not return expected power state of %s",
@@ -248,7 +256,10 @@ class AIOWifiLedBulb(LEDENETDevice):
 
     async def _async_set_power_state_with_retry(self, state: bool) -> bool:
         for idx in range(POWER_CHANGE_ATTEMPTS):
-            if await self._async_set_power_state(state, False):
+            accept_any_power_state_response = idx > 2
+            if await self._async_set_power_state(
+                state, accept_any_power_state_response
+            ):
                 _LOGGER.debug(
                     "%s: Completed power state change to %s (%s/%s)",
                     self.ipaddr,
@@ -256,6 +267,13 @@ class AIOWifiLedBulb(LEDENETDevice):
                     1 + idx,
                     POWER_CHANGE_ATTEMPTS,
                 )
+                if accept_any_power_state_response and self.is_on != state:
+                    # Sometimes these devices respond with "I turned off" and
+                    # they actually turn on when we are requesting to turn on.
+                    assert self._protocol is not None
+                    byte = self._protocol.on_byte if state else self._protocol.off_byte
+                    self._set_power_state(byte)
+                    self._set_power_transition_complete_time()
                 return True
             _LOGGER.debug(
                 "%s: Failed to set power state to %s (%s/%s)",
@@ -264,15 +282,12 @@ class AIOWifiLedBulb(LEDENETDevice):
                 1 + idx,
                 POWER_CHANGE_ATTEMPTS,
             )
-        if await self._async_set_power_state(state, True):
-            _LOGGER.debug("%s: Assuming power state change of %s", self.ipaddr, state)
-            # Sometimes these devices respond with "I turned off" and
-            # they actually even when we are requesting to turn on.
-            assert self._protocol is not None
-            byte = self._protocol.on_byte if state else self._protocol.off_byte
-            self._set_power_state(byte)
-            self._set_power_transition_complete_time()
-            return True
+        _LOGGER.error(
+            "%s: Failed to change power state to %s after %s attempts; Try rebooting the device",
+            self.ipaddr,
+            state,
+            POWER_CHANGE_ATTEMPTS,
+        )
         return False
 
     async def async_set_white_temp(
@@ -287,14 +302,14 @@ class AIOWifiLedBulb(LEDENETDevice):
         else:
             await self.async_set_levels(None, None, None, warm, cold, persist=persist)
 
-    async def async_update(self) -> None:
+    async def async_update(self, force: bool = False) -> None:
         """Request an update.
 
         The callback will be triggered when the state is recieved.
         """
         now = time.monotonic()
         assert self._protocol is not None
-        if (self._last_update_time + PUSH_UPDATE_INTERVAL) > now:
+        if not force and (self._last_update_time + PUSH_UPDATE_INTERVAL) > now:
             if self.is_on:
                 # If the device pushes state updates when on
                 # then no need to poll except for the interval
@@ -683,25 +698,33 @@ class AIOWifiLedBulb(LEDENETDevice):
             msg = self._protocol.extract_inner_message(msg)
 
         if self._protocol.is_valid_state_response(msg):
+            self._last_message["state"] = msg
             self._async_process_state_response(msg)
             self._process_state_futures()
         elif self._protocol.is_valid_power_state_response(msg):
+            self._last_message["power_state"] = msg
             self.process_power_state_response(msg)
             self._process_power_futures()
         elif self._protocol.is_valid_get_time_response(msg):
+            self._last_message["get_time"] = msg
             self.process_time_response(msg)
         elif self._protocol.is_valid_timers_response(msg):
+            self._last_message["timers"] = msg
             self.process_timers_response(msg)
             changed_state = True
         elif self._protocol.is_valid_device_config_response(msg):
+            self._last_message["device_config"] = msg
             self.process_device_config_response(msg)
             changed_state = True
         elif self._protocol.is_valid_power_restore_state_response(msg):
+            self._last_message["power_restore_state"] = msg
             self.process_power_restore_state_response(msg)
         elif self._protocol.is_valid_remote_config_response(msg):
+            self._last_message["remote_config"] = msg
             self.process_remote_config_response(msg)
             changed_state = True
         else:
+            self._last_message["unknown"] = msg
             _LOGGER.debug(
                 "%s: Ignoring unknown message: %s",
                 self.ipaddr,
